@@ -27,8 +27,6 @@
 // Qt
 #include <QDebug>
 #include <QTcpServer>
-
-#include <QDebug>
 #include <QFile>
 #include <qtest.h>
 
@@ -49,12 +47,7 @@ void FakeServer::startAndWait()
 {
     start();
     // this will block until the event queue starts
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this, &FakeServer::started, Qt::BlockingQueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "started", Qt::BlockingQueuedConnection);
-#endif
-
 }
 
 void FakeServer::dataAvailable()
